@@ -241,7 +241,7 @@ bool ndGlobalConfig::Load(const string &filename, bool profile) {
 
     ndGC_SetFlag(ndGlobalFlags::ENABLE_COREDUMPS,
       r->GetBoolean(ND_NAME_SHORT, "enable_coredumps",
-        (! profile) ? true : ndGC_ENABLE_COREDUMPS));
+        (! profile) ? false : ndGC_ENABLE_COREDUMPS));
 
     fm_buckets = (unsigned)r->GetInteger(ND_NAME_SHORT,
       "flow_map_buckets",
@@ -1142,6 +1142,16 @@ bool ndGlobalConfig::LoadCaptureSettings(void *config_reader,
 #ifdef _ND_ENABLE_CONNTRACK_COUNTERS
         nfq->conntrack_counters = conntrack_counters;
 #endif
+        string verdict = r->Get(section, "verdict", "accept");
+        if (strcasecmp(verdict.c_str(), "accept") == 0)
+            nfq->verdict = ndNFQVerdict::ACCEPT;
+        else if (strcasecmp(verdict.c_str(), "repeat") == 0)
+            nfq->verdict = ndNFQVerdict::REPEAT;
+        else {
+            fprintf(stderr,
+              "Invalid verdict type: %s\n", verdict.c_str());
+            return false;
+        }
     }
 
     return true;
