@@ -131,7 +131,7 @@ void ndDNSHintCache::Load(void) {
     default: return;
     }
 
-    if (! nd_file_exists(filename)) return;
+    if (nd_file_exists(filename) != 1) return;
 
     ifstream ifs(filename);
 
